@@ -14,31 +14,25 @@
 char * safe_memcpy(char * buf, char * newdata, int max_len)
 {
 int data_count;
-// int count;
 
 if(newdata == NULL){
    fprintf(stderr,"safe_memcpy(0): insert data is NULL.\n");
+   buf = null_free(buf);
+   return buf;
+   }
+else if(newdata[0] == (char)0x00){
+   buf = null_free(buf);
    return buf;
    }
 
-//printf("safe_memcpy(0): <%#x %c>", newdata[0], newdata[0]);
-//for(count = 1; ; count++){
-//   if(newdata[count] == 0x00){
-//      printf("<%#x %c>\n", newdata[count], newdata[count]);
-//      printf("---%s---\n", newdata);
-//      break;
-//      }
-//   printf("<%#x %c>", newdata[count], newdata[count]);
-//   }
-
 data_count = (int)strlen(newdata);
 
-if(buf != NULL){
-   free(buf);
-   buf = NULL;
+if(buf == NULL){
    buf = (char *)calloc(BUF_LEN, sizeof(char));
    }
-
+else{
+   buf = null_free(buf);
+   }
 
 if(max_len < data_count){
    if((buf = (char *)realloc(buf, (max_len + 1)))==NULL){
