@@ -54,12 +54,12 @@ if((fp = fopen(conf_filename, "r"))!=NULL){
                               }
                            break;
                   case 5 : gd.bf.c_info = safe_memcpy(gd.bf.c_info, chC, BUF_LEN);
-                           swap_mem(gd.bf.c_info, ',', '*', (int)strlen(gd.bf.c_info));
+                           swap_mem(gd.bf.c_info, ',', '*');
                            break;
                   case 6 : gd.smtp.ch_MailCc = safe_memcpy(gd.smtp.ch_MailCc, chC, IP_LEN);
                            break;
                   case 7 : gd.bf.c_name = safe_memcpy(gd.bf.c_name, chC, BUF_LEN);
-                           swap_mem(gd.bf.c_name, ',', '*', (int)strlen(gd.bf.c_name));
+                           swap_mem(gd.bf.c_name, ',', '*');
                            break;
                   case 8 : gd.fi.bat_filename = safe_memcpy(gd.fi.bat_filename, chC, BUF_LEN);
                            gd.fi.bat_filename_2 = safe_sprintf(gd.fi.bat_filename_2,BUF_LEN, "%s_2", gd.fi.bat_filename);
@@ -85,7 +85,7 @@ if((fp = fopen(conf_filename, "r"))!=NULL){
                            break;
                   case 17 : gd.td.tbufmax= strtol(chC, (char **)NULL, 10); // TBUF_MAX
                            break;
-                  case 18 : gd.ld.onoff= strtol(chC, (char **)NULL, 10); // TBUF_MAX
+                  case 18 : gd.ld.onoff= strtol(chC, (char **)NULL, 10); 
                            break;
                   case 19 : gd.fi.cron_path = safe_memcpy(gd.fi.cron_path, chC, BUF_LEN);
                            break;
@@ -95,6 +95,16 @@ if((fp = fopen(conf_filename, "r"))!=NULL){
                             gd.fi.cronlist_filename_2 = safe_sprintf(gd.fi.cronlist_filename_2, BUF_LEN, "%s_2", gd.fi.cronlist_filename);
                   case 22 : gd.cron_onoff = strtol(chC, (char **)NULL, 10);
                            break;
+                  case 23 : gd.fi.midump_filename = safe_memcpy(gd.fi.midump_filename, chC, BUF_LEN);
+                           break;
+                  case 24 : gd.td.midcount= strtol(chC, (char **)NULL, 10); // MID_MAX
+                           break;
+                  case 25 : gd.td.thread_max= strtol(chC, (char **)NULL, 10); // THREAD_MAX
+                           break;
+                  case 26 : gd.td.midint= strtol(chC, (char **)NULL, 10); // THREAD_MAX
+                           break;
+                  case 27 : gd.fi.midump_filename_2 = safe_memcpy(gd.fi.midump_filename_2, chC, BUF_LEN);
+                           break;
 
                   default : break;
                   }
