@@ -1,11 +1,6 @@
-// jpreturn.h
-// $Id: jpreturn.h,v 1.2 2007/10/01 08:14:14 sendan Exp $
-// masashi shimakura
-// japanese code return file. jpreturn.h
 // 
 // Υեjpretun.hˤϡsitar(biwa)Фܸ᤹ʸdefineʬܤƤޤ
 // ɬ EUC-JP Υ󥳡ǥ󥰤¸Ƥ
-// Windows(VC++)ξϲƤޤޤǤ
 // 
 //
 
@@ -40,7 +35,7 @@
 #define SNMP_30 "SNMPͤȥ󥰤Ǥ  "
 
 #define SOCK_1 "åȤޤǤ  "
-#define SOCK_2 "̾Ѵ˽ޤǤ  "
+#define SOCK_2 "̾Ѵ˹ԤޤǤ "
 #define SOCK_3 "ͥ˳ΩǤޤ  "
 #define SOCK_4 "֤᤮Ƥ⥳ͥ󤬳ΩǤޤǤ  "
 #define SOCK_5 "ͥ˳ΩǤޤǤ  "
@@ -52,19 +47,23 @@
 #define SOCK_11 "̾褬˽ޤ "
 #define SOCK_12 "ͽ "
 #define SOCK_13 "getsockopt()ˤڥǥ󥰥顼μ˹Ԥʤ "
-#define SOCK_14 "ꤵ줿IPۥȤƱͥåȥ¸ߤʤǽޤ "
+#define SOCK_14 "ꤵ줿IPۥȤݡֹ椬¸ߤʤǽޤ "
 #define SOCK_15 "select() Ԥǥ顼ȯƤޤ "
 #define SOCK_16 "ͥ󤬥ॢȤޤ "
 
-#define URL_1 "URL äƤơɤ200ְʳǤ  "
+#define URL_1 "URL ֤äƤơɤ200ְʳǤ  "
 #define URL_2 "URL Υǡ뤳ȤޤǤ  "
 #define URL_3 "URL Υǡ줺ॢȤޤ  "
-#define URL_4 "URL äƤơɤ200֤Ǥ  "
+#define URL_4 "URL ֤äƤơɤ200Ǥ "
 
-#define SMTP_1 "SMTP äƤơɤ200ְʳǤ  "
-#define SMTP_2 "SMTP Υǡ뤳ȤޤǤ  "
-#define SMTP_3 "SMTP Υǡ줺ॢȤޤ  "
-#define SMTP_4 "SMTP äƤơɤ200֤Ǥ  "
+#define SMTP_1 "SMTP HELOФ֤äƤơɤ200ְʳǤ  "
+#define SMTP_11 "SMTP ³Υơɤ200ְʳǤ  "
+#define SMTP_2 "SMTP HELOФƤΥǡ뤳ȤޤǤ  "
+#define SMTP_22 "SMTP ³μǡǡ򤦤ȤޤǤ "
+#define SMTP_3 "SMTP HELOФƤǡ줺ॢȤޤ  "
+#define SMTP_33 "SMTP ³Υǡ줺ॢȤޤ  "
+#define SMTP_4 "SMTP HELOФ֤äƤơɤ200Ǥ "
+#define SMTP_44 "SMTP ³֤äƤơɤ200Ǥ "
 
 #define COM_1 "¹ԥޥɤॢȤޤ  "
 #define COM_2 "ޥɤ¹ԤǤޤǤ  "
@@ -79,11 +78,42 @@
 #define ICMP_6 "ICMP RTT ͤǤ  "
 #define ICMP_7 "ICMP ѥåȤŪۥȤãǤޤǤȺǸΥ롼äƤޤ  "
 #define ICMP_8 "ICMP ѥåȤTTL0ˤʤꡢѥåȤ˴ޤ"
+#define ICMP_13 "ICMPѥåȤ뤳Ȥޤ "
 
 #define MUTEX_1 "Ʊ˼¹Խ֥åοäƤޤ  "
 
+
+#define X509_1 "ͭ°Ǥ "
+#define X509_2 "ͭ¤λڤޤ "
+#define X509_3 "ͭ¤λĤ3Ǥ "
+#define X509_4 "ͭ¤᤮ޤ "
+#define X509_5 "ͭǤ "
+
+#define X509_11 ""
+#define X509_12 ""
+#define X509_13 ""
+#define X509_14 ""
+
+#define HTTPS_1 "SLL X509 Ǥ "
+#define HTTPS_2 "SLL X509 ϰ۾֤ƤޤΥǡǤ "
+
+
 #define MONITOR_ERR_1  "ʤƻ°ꤷƤޤ㤨SNMPȤʤ饤ȤSNMP꤬Ƥޤ  "
 
+#define BLOCK_TEST_1 "ƻ˶ιܤޤޤޤ "
+#define BLOCK_TEST_2 "ƻΥǡ礭 "
+#define BLOCK_TEST_3 "ƻΥǥߥο "
+#define BLOCK_TEST_4 "ƻƬब'#'Ǥ롢̾盧߾֤Ǥ "
+#define BLOCK_TEST_5 " "
+#define BLOCK_TEST_6 "۾ "
+#define BLOCK_TEST_7 "ƻ˲餫꤬褦Ǥ "
+
+#define ERR_MAIL_1 "Ļδְ㤤 "
+#define ERR_MAIL_2 "Υ֥å˳Ƥ줿Ļ֤äƤޤ "
+#define ERR_MAIL_3 "Ļܤ¿١ιԤĻ뤵Ƥޤ "
+
+
+
 #endif
 
 
