@@ -4,6 +4,7 @@
 
 /* --- sitar.c --- */
 int safe_exit(char *);
+int signal_exit(void);
 int check_alget(char *);
 int life_put(void);
 int start_neg(void);
@@ -17,7 +18,10 @@ int life_pthread(void);
 void * scan_block(int);
 int sitar_scan(void);
 int sitar_cron(void);
-
+int miname_dump(char *);
+int miname_install(void);
+int th_miname_dump(void);
+int midump_remove(char *);
 
 /* --- confset.c --- */
 int conf_set(char *);
@@ -36,6 +40,7 @@ int optin(int, char *[]);
 /* --- malloc_set --- */
 int scan_malloc_set(private_data_t *);
 int scan_malloc_free(private_data_t *);
+int scan_malloc_null(private_data_t *);
 int m_exit(int);
 
 
@@ -46,9 +51,12 @@ int malloc_set(void);
 int malloc_set_free(void);
 int malloc_set2(void);
 int malloc_set2_free(void);
+int private_malloc_set(void);
 int safree(int);
+int sanull(int);
 int sacalloc(int);
 int satmpfree(void);
+int satmpnull(void);
 int satmpcalloc(void);
 
 /* --- scan_port.c --- */
@@ -63,7 +71,8 @@ int scan_snmp(struct scan_buf *);
 int scan_comand(private_data_t *);
 
 /* --- filestat.c --- */
-char * stat_check(char *, char *, int, int *);
+// char * stat_check(char *, char *, int, int *);
+char * stat_check(char *, char *, int *);
 
 /* --- times.c --- */
 int hloop(int, int, int, int, int, int);
