@@ -37,8 +37,13 @@ unsigned long resoip;
 struct sockaddr_in my_addr;
 fd_set rfds;
 struct timeval tv;
-char * recvdata = NULL;
-char * senddata = NULL;
+char recvd[BUF_LEN];
+char sendd[BUF_LEN];
+char * recvdata = recvd;
+char * senddata = sendd;
+
+memset(recvdata, 0x00, BUF_LEN);
+memset(senddata, 0x00, BUF_LEN);
 
 ret = -1;
 errno = 0;
@@ -49,16 +54,12 @@ dcount = 0;
 printf("DHW: scan_dhw_connect(1): DHW COMMAND %s\n", comand);
 #endif
 
-if((recvdata = (char *)calloc(BUF_LEN, sizeof(char)))==NULL){ exit(1);}
-if((senddata = (char *)calloc(BUF_LEN, sizeof(char)))==NULL){ exit(1);}
 
 if((sk = socket(AF_INET, SOCK_STREAM, 0))==-1){
    fprintf(stderr,"scan_dhw URL=%s Port=%d tcp %s", url_dom, port, SOCK_1);
    backdata=safe_sprintf(backdata, BUF_MAX,
     "URL=%s Port=%d tcp %s", url_dom, port, SOCK_1);
    * pst = -1;
-   free(recvdata);
-   free(senddata);
    return backdata;
    }
 
@@ -73,8 +74,6 @@ if(0 == (int)my_addr.sin_addr.s_addr || resoip == (int)NULL){
     SOCK_2, url_dom, (int)my_addr.sin_addr.s_addr);
    close(sk);
    * pst = -1;
-   free(recvdata);
-   free(senddata);
    return backdata;
    }
 
@@ -95,7 +94,7 @@ if(re >= 0){
    backdata=safe_sprintf(backdata,BUF_MAX,
     "URL=%s Port=%d %s", url_dom, port, SOCK_5);
    #ifdef URL_BUG
-   printf("URL: scan_url_connect(4): CONNECT SUCCESS %s\n", backdata);
+   printf("URL: scan_dhw_connect(4): CONNECT SUCCESS %s\n", backdata);
    #endif
    goto notselect;
    }
@@ -119,8 +118,6 @@ if(errno == EINPROGRESS){
          fcntl(sk, F_SETFL, 0);
          close(sk);
          * pst = -1;
-         free(recvdata);
-         free(senddata);
          return backdata;
          }
       // select ぃゃ\めAムめuゃ
@@ -135,8 +132,6 @@ if(errno == EINPROGRESS){
          fcntl(sk, F_SETFL, 0);
          close(sk);
          * pst = -1;
-         free(recvdata);
-         free(senddata);
          return backdata;
          }
       // 時間内に掁E続出杁Eたのぃ@LoopOut
@@ -166,8 +161,6 @@ if(errno == EINPROGRESS){
       #endif
       close(sk);
       * pst = -1;
-      free(recvdata);
-      free(senddata);
       return backdata;
       }
 
@@ -181,8 +174,6 @@ if(errno == EINPROGRESS){
          #endif
          close(sk);
          * pst = -1;
-         free(recvdata);
-         free(senddata);
          return backdata;
          }
 
@@ -193,7 +184,14 @@ if(errno == EINPROGRESS){
          #ifdef DHW_BUG
          printf("DHW: scan_dhw_connect(8): 1 SO_ERROR else %d -%s\n", retval, backdata);
          #endif
-         senddata=safe_sprintf(senddata, BUF_MAX, "%s\n\n", comand);
+
+         if((strlen(comand) + 5) < BUF_LEN){
+            sprintf(senddata, "%s\n\n", comand);
+            }
+         else{
+            sprintf(senddata, "%s\n\n", "/bin/long_long_command! ");
+            }
+
          #ifdef DHW_BUG
          printf("DHW: scan_dhw_connect(9): set_request*send-- %s --\n", senddata);
          #endif 
@@ -222,8 +220,6 @@ if(errno == EINPROGRESS){
                fcntl(sk, F_SETFL, 0);
                close(sk);
                * pst = -1;
-               free(recvdata);
-               free(senddata);
                return backdata;
                }
 
@@ -238,8 +234,6 @@ if(errno == EINPROGRESS){
                fcntl(sk, F_SETFL, 0);
                close(sk);
                * pst = -1;
-               free(recvdata);
-               free(senddata);
                return backdata;
                }
 
@@ -269,6 +263,7 @@ if(errno == EINPROGRESS){
                   }
 
                if(ret == -1){
+                  swap_mem(recvdata, ',', ' ');
                   backdata=safe_memcpy(backdata, recvdata, BUF_LEN);
                   }
 
@@ -279,8 +274,6 @@ if(errno == EINPROGRESS){
                fcntl(sk, F_SETFL, 0);
                close(sk);
                * pst = ret;
-               free(recvdata);
-               free(senddata);
                return backdata;
                }
             }
@@ -291,8 +284,6 @@ if(errno == EINPROGRESS){
          fcntl(sk, F_SETFL, 0);
          close(sk);
          * pst = ret;
-         free(recvdata);
-         free(senddata);
          return backdata;
          }
       }
@@ -311,8 +302,6 @@ printf("DHW: scan_dhw_connect(16): not connection last out\n");
 close(sk);
 * pst = -1;
 
-free(recvdata);
-free(senddata);
 return backdata;
 
 }
