@@ -15,14 +15,16 @@ char * scan_host(char * ip_data, char * ip_addr, char * backdata, int timeout, i
 {
 unsigned long addr;
 unsigned char inip_addr[4];
-char * ch_addr = (char *)calloc(5, sizeof(char));
+char ch[256];
+char * ch_addr = ch;
+
+memset(ch_addr, 0x00, 256);
 
 backdata = resolvename(backdata, ip_addr, timeout, &addr);
-// addr = resolvename(ip_addr, timeout);
 
 memcpy(inip_addr, &addr, sizeof(inip_addr));
 
-ch_addr = safe_sprintf(ch_addr, BUF_MAX, "%d.%d.%d.%d",
+sprintf(ch_addr,"%d.%d.%d.%d",
   inip_addr[0],
   inip_addr[1],
   inip_addr[2],
@@ -34,7 +36,6 @@ if(0 == (int)addr){
    #ifdef HOST_BUG
    printf("HOST: scan_host(1): NOT RESOLV NAME %s\n", backdata);
    #endif
-   free(ch_addr);
    * stat = -1;
    return backdata;
    }
@@ -44,7 +45,6 @@ else{
       #ifdef HOST_BUG
       printf("HOST: scan_host(2): RESOLV NAME %s\n", backdata);
       #endif
-      free(ch_addr);
       * stat = 1;
       return backdata;
       }
@@ -53,13 +53,11 @@ else{
       #ifdef HOST_BUG
       printf("HOST: scan_host(3): RESOLV NAME %s\n", backdata);
       #endif
-      free(ch_addr);
       * stat = -1;
       return backdata;
       }
    }
 
-free(ch_addr);
 * stat = 1;
 return backdata;
 }
