@@ -20,17 +20,6 @@
 
 
 
-
-/* 1-> Ipsddr 2-> return data,, return status code 0=open or=close */
-/* int scan_icmp(char [], char *);
-int make_icmp8_packet(struct icmp *, int, int);
-int tvsub(struct timeval *, struct timeval *); 
-u_short checksum(u_short *, int);
-int scan_icmp(char [], char *, int);
-*/
-
-
-
 /* ------------ TVSUB --------------- */
 int tvsub(struct timeval *out, struct timeval *in) 
 {
@@ -91,7 +80,7 @@ return 0;
 
 
 /*----------------- SCAN ICMP --------------------*/
-char * scan_icmp(char ip_addr[], char * backdata, int timeout, int * stat, int coe)
+char * scan_icmp(char * url_data, char * backdata, int timeout, int * stat, int coe)
 {
 int send_sk, hlen, i;
 float rtt;
@@ -99,26 +88,41 @@ unsigned long resoip;
 char send_buff[1024];
 char recv_buff[1024];
 char ipa2[IP_LEN];
+char ipx[BUF_URL];
+char * ip_addr = ipx;
+char pas[BUF_URL];
+char * url_pass = pas;
 char * ip_addr2 = ipa2;
 struct sockaddr_in send_addr;
 struct timeval tv;
 struct ip *ip;
 fd_set select_fd;
 
+// http:// とかつけちゃった場合の救済
+memset(ip_addr, 0x00, BUF_URL);
+memset(url_pass, 0x00, BUF_URL);
+
+urldompass_port(url_data, ip_addr, url_pass, strlen(url_data));
+
+
+// 初期化
 rtt = 0.0;
 i = 0;
 
-// 名前见v汃R
 memset((char *)&send_addr, 0, sizeof(struct sockaddr_in));
+memset(ipa2, 0x00, IP_LEN);
+memset(send_buff, 0x00, 1024);
+memset(recv_buff, 0x00, 1024);
+
 send_addr.sin_family = AF_INET;
 
+// 名前解決
 backdata = resolvename(backdata, ip_addr, timeout, &resoip);
 send_addr.sin_addr.s_addr = resoip;
 
-
 if(0 == (int)send_addr.sin_addr.s_addr || resoip == (int)NULL){
-   backdata = safe_sprintf(backdata,BUF_MAX,
-    "%s %s %d\n", SOCK_2, ip_addr, (int)send_addr.sin_addr.s_addr);
+// backdata = safe_sprintf(backdata,BUF_MAX, "%s %s %d\n", SOCK_2, ip_addr, (int)send_addr.sin_addr.s_addr);
+   backdata = safe_sprintf(backdata,BUF_MAX, "%s %s\n", SOCK_2, ip_addr);
    #ifdef ICMP_BUG
    printf("ICMP: scan_icmp(0): START %s\n", backdata);
    #endif
@@ -132,9 +136,7 @@ ip_addr2 = inet_ntoa(send_addr.sin_addr);
 printf("ICMP: scan_icmp(1): ICMP host<%s> ip<%s>\n", ip_addr, ip_addr2);
 #endif
 
-
-
-// RAW SOCKET 生成
+// RAW socketの生成
 if((send_sk = socket(AF_INET, SOCK_RAW, IPPROTO_ICMP)) < 0){
    backdata=safe_sprintf(backdata, BUF_MAX,
     "IP=%s %s", ip_addr, ICMP_1);
@@ -145,8 +147,7 @@ if((send_sk = socket(AF_INET, SOCK_RAW, IPPROTO_ICMP)) < 0){
    return backdata;
    }
 
-
-// ICMP packetぃ生成 ＆ SEND
+// ICMPパケットの生成と送信
 make_icmp8_packet((struct icmp *)(long int)send_buff, 72, i);
 if(sendto(send_sk, (char *)&send_buff, 72, 0, (struct sockaddr *)(long int)&send_addr, sizeof(send_addr)) < 0){
    backdata=safe_sprintf(backdata, BUF_MAX,"IP=%s %s",
@@ -159,20 +160,20 @@ if(sendto(send_sk, (char *)&send_buff, 72, 0, (struct sockaddr *)(long int)&send
    return backdata;
    }
 
-// select timeout ぃ訃
-tv.tv_sec = 0;
-tv.tv_usec =(timeout * 100000);
+// select()の待ち時間をimeout * 1秒に設定
+tv.tv_sec = timeout;
+tv.tv_usec = 0;
 
 while(1){
    FD_ZERO(&select_fd);
    FD_SET(send_sk, &select_fd);
 
-   // select() 待ち
+   // select()でtime out をまつ
    if(select(send_sk + 1, &select_fd, NULL, NULL, &tv) <= 0){
       break;
       }
 
-   // パケット受け取り
+   // FDに変化があった場合はrecvする
    if(recvfrom(send_sk, recv_buff, 1024, 0, NULL, NULL) < 0){
       backdata=safe_sprintf(backdata, BUF_MAX,"IP=%s %s",
        ip_addr, ICMP_3);
@@ -184,15 +185,15 @@ while(1){
       return backdata;
       } 
 
+   // 戻ったパケットを判断
    ip = (struct ip *)(long int)recv_buff;
    hlen = ip->ip_hl << 2;
 
-   // 送\B元アドレゃPぃB臃F分のめuドレゃPぃ比V
    if(ip->ip_src.s_addr == send_addr.sin_addr.s_addr){
       struct icmp *icmp;
       icmp = (struct icmp *)(long int)(recv_buff + hlen);
 
-      // 戃TりパゃAットぃ彁u式がICMP_ECHOREPLYぃ堃G
+      // 戻ったパケットのRTTを判断  RTTの時間は閾値が1の場合に100msec
       if(icmp->icmp_type == ICMP_ECHOREPLY){
          gettimeofday(&tv, (struct timezone *)0);
          tvsub(&tv, (struct timeval *)(icmp->icmp_data));
@@ -232,7 +233,7 @@ while(1){
 
          }
 
-      // TYPEがICMO_ECHOぃ@、自分自躃H宛のゃBゃEッV要Aのパケットぃ@ある堃G合w
+      // 戻ったパケットがエコーリプライの場合、正常
       else if(icmp->icmp_type == ICMP_ECHO){
          #ifdef ICMP_BUG
          printf("ICMP: scan_icmp(7): RECV RAW type<%d> sendip<%d> inip<%d>\n",
@@ -240,7 +241,7 @@ while(1){
          #endif
          }
 
-      // TYPEがICMP_UNREACHぃ@、ホゃPトに刁|達出杁EぃFい  // ここぃ@ぃb焁B
+      // 到達出来ないと帰った場合
       else if(icmp->icmp_type == ICMP_UNREACH){
          backdata=safe_sprintf(backdata,BUF_MAX,"%s :RTT=%7.4fms %s",
             inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr)),
@@ -252,21 +253,6 @@ while(1){
          * stat = -1;
          return backdata;
          }
-
-      // TYPEがICMP_TIMXCEED、TTLが0ぃ@パケットが砃G棄されました  // ここぃ@ぃb焁B
-      else if(icmp->icmp_type == ICMP_UNREACH){
-         backdata=safe_sprintf(backdata,BUF_MAX,"%s :RTT=%7.4fms %s",
-            inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr)),
-            tv.tv_sec*1000.0 + tv.tv_usec/1000.0, ICMP_8);
-         #ifdef ICMP_BUG
-         printf("ICMP: scan_icmp(9): RECV RAW %s type<%d>\n", backdata, icmp->icmp_type);
-         #endif
-         close(send_sk);
-         * stat = -1;
-         return backdata;
-         }
-
-      // TYPEがそれTE外の堃G合VもぁBろんゃBッDッV	
       else{
          backdata=safe_sprintf(backdata,BUF_MAX,"%s :RTT=%7.4fms %s",
             inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr)),
@@ -280,7 +266,6 @@ while(1){
          }
 
       }
-   // 送\B元アドレゃPぃB臃F分のめuドレゃPぃ比Vが歁vしくぃF
    else{
       #ifdef ICMP_BUG
       printf("ICMP: scan_icmp(11): RECV RAW DATA sendip<%d> inip<%d>\n",
@@ -292,7 +277,7 @@ while(1){
 
 rtt = tv.tv_sec*1000.0 + tv.tv_usec/1000.0;
 backdata=safe_sprintf(backdata,BUF_MAX,
- "IP=%s :RTT=%7.4fms %s", ip_addr, rtt, ICMP_3);
+ "IP=%s :RTT=%7.4fms %s", ip_addr, rtt, ICMP_13);
 #ifdef ICMP_BUG
 printf("ICMP: scan_icmp(12): LAST %s\n", backdata);
 #endif
@@ -302,6 +287,3 @@ close(send_sk);
 return backdata;
 }
 
-
-
-
