@@ -229,7 +229,8 @@ send_time = (bk_ntpdata.tranststamp/0x100000000ULL) - JAN_1970;
 
 double my_start =(double)tv_tts.tv_sec + (double)tv_tts.tv_usec * 1/(1000 * 1000);
 double my_stop = (double)tv_vts.tv_sec + (double)tv_vts.tv_usec * 1/(1000 * 1000);
-double ldtimeout = (double)(timeout * 100000) * 1/(1000 * 1000);
+// double ldtimeout = (double)(timeout * 100000) * 1/(1000 * 1000);  // 0.1
+double ldtimeout = (double)(timeout * 1000000) * 1/(1000 * 1000);   // 1
 
 // printf("start %lf,  stop %lf\n", my_start, my_stop);
 // printf("recv %lf,  send %lf\n", recv_time, send_time);
