@@ -23,12 +23,18 @@ int scan_udp_connect(int, char *, char *, int);
 
 
 /*----------------- SCAN UDP CONNECT --------------------*/
-char * scan_udp_connect(int port, char * ip_addr, char * backdata, int timeout, int * stat)
+char * scan_udp_connect(int port, char * url_data, char * backdata, int timeout, int * stat)
 {
 char ipa2[IP_LEN];
 char * ip_addr2 = ipa2;
 char buff[1024];
-int send_sk, recv_sk, select_stat;
+
+char ip[BUF_URL];
+char * ip_addr = ip;
+char pas[BUF_URL];
+char * url_pass = pas;
+
+int send_sk, recv_sk, select_stat, port2;
 unsigned long resoip;
 struct icmp *icmp;
 struct sockaddr_in send_addr;
@@ -37,12 +43,24 @@ fd_set select_fd;
 
 send_addr.sin_family = AF_INET;
 
+
+memset(ip_addr, 0x00, BUF_URL);
+memset(url_pass, 0x00, BUF_URL);
+
+// portの設定よりもURLに含まれるポートを優先する
+port2 = urldompass_port(url_data, ip_addr, url_pass, strlen(url_data));
+if(port2 > 0){
+   port = port2;
+   }
+
+
+
 backdata = resolvename(backdata, ip_addr, timeout, &resoip);
 send_addr.sin_addr.s_addr = resoip;
 
 if(0 == (int)send_addr.sin_addr.s_addr || resoip == (int)NULL){
-   backdata=safe_sprintf(backdata,BUF_MAX,"%s %s %d\n",
-    SOCK_2, ip_addr, (int)send_addr.sin_addr.s_addr);
+// backdata=safe_sprintf(backdata,BUF_MAX,"%s %s %d\n", SOCK_2, ip_addr, (int)send_addr.sin_addr.s_addr);
+   backdata=safe_sprintf(backdata,BUF_MAX,"%s %s\n", SOCK_2, ip_addr);
    #ifdef UDP_BUG
    printf("UDP: scan_udp_connect(1): START %s\n", backdata);
    #endif
@@ -56,7 +74,6 @@ ip_addr2 = inet_ntoa(send_addr.sin_addr);
 printf("UDP: scan_udp_connect(2): UDP host<%s> ip<%s>\n",ip_addr2, ip_addr);
 #endif
 
-// UDP ゃXゃAットをXる
 if((send_sk = socket(AF_INET, SOCK_DGRAM, 0)) < 0){
    backdata=safe_sprintf(backdata,BUF_MAX,
     "IP=%s Port=%d UDP %s", ip_addr, port, SOCK_1);
@@ -67,7 +84,6 @@ if((send_sk = socket(AF_INET, SOCK_DGRAM, 0)) < 0){
    return backdata;
    }
 
-// RAWゃXゃAットをXる
 if((recv_sk = socket(AF_INET, SOCK_RAW, IPPROTO_ICMP)) < 0){
    backdata=safe_sprintf(backdata,BUF_MAX,
     "IP=%s Port=%d ICMP %s", ip_addr, port, SOCK_1);
@@ -78,7 +94,6 @@ if((recv_sk = socket(AF_INET, SOCK_RAW, IPPROTO_ICMP)) < 0){
    return backdata;
    }
 
-// UDPゃXゃAットぃ送\B
 send_addr.sin_port = htons(port);
 sendto(send_sk, NULL, 0, 0, (struct sockaddr *)(long int)&send_addr, sizeof(send_addr));
 
@@ -89,20 +104,17 @@ while(1){
    FD_ZERO(&select_fd);
    FD_SET(recv_sk, &select_fd);
 
-   // selectぃ@ゃ\めAムめuゃ
    if((select_stat = select(recv_sk + 1, &select_fd, NULL, NULL, &tv)) > 0){
       struct ip *ip;
       int hlen;
       int ports;
-      // RAWゃXゃAットぃ受け取り
       if(recvfrom(recv_sk, buff, 1024, 0, NULL, NULL) != 56){
          #ifdef UDP_BUG
          printf("UDP: scan_udp_connect(5): ");
-         printf("(%d %d)ゃIめAゃR違いぃパケットを受け取りました、@めから\n", recv_sk, select_stat);
          #endif
          continue;
          }
-      // 受\Bパケットぃ評ZB
+
       ip = (struct ip *)(long int)buff;
       hlen = ip->ip_hl << 2;
       icmp = (struct icmp*)(buff + hlen);
@@ -113,7 +125,6 @@ while(1){
          || (ports != port)){
          #ifdef UDP_BUG
          printf("UDP: scan_udp_connect(6): ");
-         printf("(%d %d)ポートN達ぃ@ぃFいICMPパケットを受け取ぁvぃぃZす、@めから\n", recv_sk, select_stat);
          #endif
          continue;
          }
@@ -122,7 +133,6 @@ while(1){
            "IP=%s Port=%d UDP %s", ip_addr, port, SOCK_7);
          #ifdef UDP_BUG
          printf("UDP: scan_udp_connect(7): ");
-         printf("(%d %d)ポートN達ICMPパケットを受け取ぁvぃぃZす、エッDッV\n", recv_sk, select_stat);
          #endif
          close(send_sk);
          close(recv_sk);
@@ -139,7 +149,6 @@ while(1){
          ip_addr, port, (se==NULL)?"unknown":se->s_name, SOCK_3);
       #ifdef UDP_BUG
       printf("UDP: scan_udp_connect(8): RECV %s", backdata);
-      printf("(%d %d) ゃ\めAムめuゃトしぃZした\n", recv_sk, select_stat);
       #endif
       close(send_sk);
       close(recv_sk);
@@ -149,7 +158,6 @@ while(1){
 
    #ifdef UDP_BUG
    printf("UDP: scan_udp_connect(9): RECV %s", backdata);
-   printf("(%d %d)BREAKします。\n", recv_sk, select_stat);
    #endif
    break;
    }
@@ -158,7 +166,6 @@ backdata=safe_sprintf(backdata,BUF_MAX,
  "IP=%s Port=%d UDP %s", ip_addr, port, SOCK_5);
 #ifdef UDP_BUG
 printf("UDP: scan_udp_connect(10): END %s", backdata);
-printf("(%d %d)戃TりパゃAットをうけとれませんぃ@した。エッDッV\n", recv_sk, select_stat);
 #endif
 
 
