@@ -2,6 +2,8 @@
 // $Id: sitar_scan.h,v 1.2 2007/10/02 10:21:54 sendan Exp $
 // masashi shimakura
 
+#include<time.h>
+#include<pthread.h>
 
 #ifndef _SITAR_SCAN_H_
   #define _SITAR_SCAN_H_
@@ -16,6 +18,7 @@
     #define IP_LEN 64
   #endif
 
+  #define BUF_URL 1024
 
   /* RESOLV DEBUG */
 //  #define RESOLV_DEBUG
@@ -41,10 +44,25 @@
   /* SNTP BUG */
 //  #define SNTP_BUG                   
 
-//  struct buf_data{
-//     char * recvdata;
-//     char * senddata;
-//     };
+  /* SSL/TSL BUG */
+//  #define SSL_BUG
+
+
+
+typedef struct stred stred_t;
+
+struct stred{
+   char back_data[1024];
+   char name_data[1024];
+   int time;
+   int check;
+   pthread_t t_ret;
+   pthread_t t_chk;
+// pthread_mutex_t back_data_mutex;
+   };
+
+
+
 
   /* --- scan_icmp.c --- */
   char * scan_icmp(char *, char *, int, int *, int);
@@ -55,13 +73,20 @@
   /* --- scan_tcpport.c --- */
   char * scan_tcp_connect(int, char *, char *, int, int *);
 
-  /* --- scan_urlport.c --- */
+  /* --- scan_url_connect.c --- */
   char * scan_url_connect(int, char *, char *, int, int *);
 
+  /* --- scan_ssl_connect.c --- */
+  char * scan_ssl_command(int, char *, char *, int, long int, int *, char *);
+  int count_memcpy3(char out[], char * data, int start, int plus);
+
   /* --- scan_smtpport.c --- */
   char * scan_smtp_connect(int, char *, char *, int, int *);
-//unsigned long resolvename(char *, int);
   char * resolvename(char *, char *, int, unsigned long *);
+  char * out_resolvename(char *, char *, int, unsigned long *);
+  unsigned long resolve_name(char *name);
+  time_t cert_time_get(char * data);
+  char * th_resolv(char * name, char * back, int interval, int out);
 
   /* --- scan_dhwport.c --- */
   char * scan_dhw_connect(char *, int, char *, char *, int, int *);
@@ -76,6 +101,13 @@
   /* --- scan_host.c --- */
   char * scan_host(char *, char *, char *, int, int *);
 
+  /* scan_urlport() */
+  int urldompass_port(char *, char *, char *, int); 
+  char * set_request(char *, char *, char *);
+  int self_set_request(char *, char *, char *, int);
+  char * check_recvdata(char *, char *, int *);
+  int self_check_recvdata(char *, char *);
+
 #endif
 
 
