@@ -70,7 +70,7 @@ if(oldtime == pd->life.in_life[0]){
 
       // 本文をつくります
       swapdata = safe_sprintf(swapdata, BUF_MAX, "%s\n\n%s\n\n%s\n", pd->rec.info, pd->life.swap4, CL_VAR);
-      swap_mem(swapdata, '\n', (char)0x01, strlen(swapdata));
+      swap_mem(swapdata, '\n', (char)0x01);
 
       mail_grsend(pd->mail.server,
                pd->mail.from,
