@@ -26,6 +26,8 @@ int port;
 int timeout;
 
 // char * charset = "X-Mailer: zither_server\r\n";
+char * swap;
+char * message;
 char * charset = "X-Mailer: ";
 char * charversion = CL_VAR;
 char * charkaigyou = "\r\n";
@@ -37,6 +39,13 @@ stat = 0;
 port = 25;
 timeout = 6;
 
+// Message_ID を作る
+swap = (char *)calloc(256, sizeof(char));
+message = (char *)calloc(512, sizeof(char));
+swap = message_id(swap, "Zither_server", mdd->iserver);
+message = safe_sprintf(message, BUF_LEN,"Message-Id: <%s>", swap);
+free(swap);
+
 // スレッドのデタッチ
 pthread_detach(pthread_self());
 
@@ -148,7 +157,7 @@ if(0 > (socket_send(mdd->sk, mdd->swap, timeout))){
 
 
 // 拡張ヘッダーを作成
-mdd->swap2 = safe_sprintf(mdd->swap2, BUF_MAX, "%s %s\r\n", charenc, mdd->pri);
+mdd->swap2 = safe_sprintf(mdd->swap2, BUF_MAX, "%s\r\n%s %s\r\n", message, charenc, mdd->pri);
 
 mdd->swap = safe_sprintf(mdd->swap, BUF_MAX,"%s%s%s%s%s%s",
   charset, charversion, charkaigyou, mdd->swap2, charcontyp, chartraenc);
@@ -240,6 +249,8 @@ if(stat < 0){
 mailend :;
 
 // 戦後処理
+
+free(message);
 close(mdd->sk);
 mail_free(mdd);
 free(mdd);
