@@ -22,6 +22,10 @@ int malloc_set(void)
 {
 /* selects data base */
 if((gd.db_select=(char*)calloc(IP_LEN, sizeof(char)))==NULL){exit(1);}
+/* bcc seting use */
+if((gd.on_bcc=(char*)calloc(IP_LEN, sizeof(char)))==NULL){exit(1);}
+/* cron onoff set */
+gd.cron_onoff = 0;
 /*  postgres socket */
 if((gd.pg.postgres_data=(char*)calloc(IP_LEN, sizeof(char)))==NULL){exit(1);}
 if((gd.pg.pg_webserver=(char*)calloc(IP_LEN, sizeof(char)))==NULL){exit(1);}
