@@ -24,7 +24,7 @@ char * putlog_data = (char *)calloc(BUF_DEFLEN, sizeof(char));
 
 ret = 0;
 
-swap_mem(data, '\n', ' ', (int)strlen(data));
+swap_mem(data, '\n', ' ');
 
 putlog_data = safe_sprintf(putlog_data, BUF_MAX, "%d.%d.%d.%d,%s,%s\n",
   chIpadd[0],
