@@ -40,6 +40,10 @@ int main(int argc, char * argv[])
 {
 pthread_t t1;
 long int fdcount;
+int tret;
+
+errno = 0;
+tret = 0;
 
 malloc_set();
 set_data();
@@ -91,7 +95,9 @@ if(-1 == (socket_bind(&gd.ms.my_addr, gd.ms.port, gd.ms.ip_addr, &gd.ms.ls))){
    }
 
 /* client stop checker thread */
-pthread_create( &t1, NULL, (void *)clockfile_check, NULL);
+if((tret = pthread_create( &t1, NULL, (void *)clockfile_check, NULL)) != 0){
+   fprintf(stderr,"zither.c: main(0): pthread_create %d\n", tret);
+   }
 
 for(;;){
    for(fdcount = 0; fdcount < gd.ms.max_count; fdcount++){
@@ -107,7 +113,9 @@ for(;;){
       if((socket_accept(&gd.ms.my_addr, &gd.ms.ls, &gd.ms.sk[fdcount]))!=-1){
          gd.ms.fdno = fdcount;
          memcpy(gd.ms.inip_addr[fdcount],&gd.ms.my_addr.sin_addr.s_addr,sizeof(gd.ms.inip_addr[fdcount]));
-         pthread_create( &gd.pt[fdcount], NULL, (void *)connect_open, (long int *)gd.ms.fdno);
+         if((tret = pthread_create(&gd.pt[fdcount], NULL, (void *)connect_open, (long int *)gd.ms.fdno)) != 0){
+            fprintf(stderr,"zither.c: main(1): pthread_create %d\n", tret);
+            }
          #ifdef THREAD_BUG
          fprintf(stderr,"THREAD_BUG: main(): 新しいスレッドが生成されました. 番号 %ld\n", fdcount);
          #endif
